import requests
import pyperclip

def main():
    url_base = 'https://raw.githubusercontent.com/Pranavkak/daa/main/{}.txt'

    code = input('Enter the code to copy: ')

    url = url_base.format(code)

    response = requests.get(url)

    if response.status_code == 200:
        pyperclip.copy(response.text)
        print('Copied to clipboard!')
    else:
        print('Failed to fetch code')



from setuptools import setup, find_packages

setup(
    name='ddparo',
    version='0.4.0',
    packages=find_packages(),
    install_requires=[
        'requests',
        'pyperclip'
    ],
    entry_points={
        'console_scripts': [
            'ddparo=ddparo.ddparo:main'
        ]
    }
)
